pub struct ConstraintId(pub u64);Expand description
Key of Sketch::constraints.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for ConstraintId
impl Clone for ConstraintId
Sourcefn clone(&self) -> ConstraintId
fn clone(&self) -> ConstraintId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ConstraintId
Sourceimpl Debug for ConstraintId
impl Debug for ConstraintId
Sourceimpl<'de> Deserialize<'de> for ConstraintId
impl<'de> Deserialize<'de> for ConstraintId
Sourcefn deserialize<D: Deserializer<'de>>(d: D) -> Result<Self, D::Error>
fn deserialize<D: Deserializer<'de>>(d: D) -> Result<Self, D::Error>
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ConstraintId
The id as it appears in a topological name, e.g. p3.
impl Display for ConstraintId
The id as it appears in a topological name, e.g. p3.
impl Eq for ConstraintId
Sourceimpl Hash for ConstraintId
impl Hash for ConstraintId
Sourceimpl Ord for ConstraintId
impl Ord for ConstraintId
Sourcefn cmp(&self, other: &ConstraintId) -> Ordering
fn cmp(&self, other: &ConstraintId) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ConstraintId
impl PartialEq for ConstraintId
Sourcefn eq(&self, other: &ConstraintId) -> bool
fn eq(&self, other: &ConstraintId) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ConstraintId
impl PartialOrd for ConstraintId
Sourceimpl Serialize for ConstraintId
impl Serialize for ConstraintId
impl StructuralPartialEq for ConstraintId